@@ -48,7 +48,7 @@ Transfer::Transfer(TransferGroup * parent, TransferFactory * factory,
       m_totalSize(0), m_downloadedSize(0), m_uploadedSize(0),
       m_percent(0), m_downloadSpeed(0), m_uploadSpeed(0),
       m_uploadLimit(0), m_downloadLimit(0), m_isSelected(false),
-      m_capabilities(0), m_visibleUploadLimit(0), m_visibleDownloadLimit(0),
+      m_capabilities(), m_visibleUploadLimit(0), m_visibleDownloadLimit(0),
       m_runningSeconds(0), m_ratio(0), m_handler(nullptr), m_factory(factory)
 {
     Q_UNUSED(e)
@@ -62,7 +62,7 @@ void Transfer::setCapabilities(Capabilities capabilities)
 {
     if (m_capabilities != capabilities) {
         m_capabilities = capabilities;
-        emit capabilitiesChanged();
+        Q_EMIT capabilitiesChanged();
     }
 }
 
