@@ -16,10 +16,9 @@
 
 #include "kget_debug.h"
 
+#include <QDebug>
 #include <QDomElement>
 
-#include <qdebug.h>
-
 K_PLUGIN_CLASS_WITH_JSON(ChecksumSearchFactory, "kget_checksumsearchfactory.json")
 
 ChecksumSearchFactory::ChecksumSearchFactory(QObject *parent, const QVariantList &args)
